
Log TLS connection failures
-------

**Description:**

Whenever a TLS connection fails, then these failures should be logged


**Solution:**

Verify that backend TLS connection failures are logged.

	